@@ -405,12 +405,10 @@ SEXP Mmatrix(SEXP args)
 #endif
 
 	PROTECT(ans = allocMatrix(TYPEOF(vals), nr, nc));
-	if (lendat) {
-		if (isVector(vals))
-			copyMatrix(ans, vals, byrow);
-		else
-			copyListMatrix(ans, vals, byrow);
-	} else if (isVector(vals)) { /* fill with NAs */
+	if (isVector(vals)) {
+	    if(lendat)
+		copyMatrix(ans, vals, (Rboolean) byrow);
+	    else { /* fill with NAs */
 		R_xlen_t N = (R_xlen_t) nr * nc, i;
 		switch (TYPEOF(vals)) {
 		case STRSXP:
@@ -447,6 +445,7 @@ SEXP Mmatrix(SEXP args)
 			/* don't fill with anything */
 			;
 		}
+	    }
 	}
 	if (!isNull(dimnames)&& length(dimnames) > 0)
 		ans = dimnamesgets(ans, dimnames);
@@ -530,7 +529,7 @@ SEXP m_encodeInd(SEXP ij, SEXP di, SEXP orig_1, SEXP chk_bnds)
 {
 	SEXP ans;
 	int *ij_di = NULL, n, nprot=1;
-	Rboolean check_bounds = asLogical(chk_bnds), one_ind = asLogical(orig_1);
+	int check_bounds = Rf_asLogical(chk_bnds), one_ind = Rf_asLogical(orig_1);
 
 	if (TYPEOF(di) != INTSXP) {
 		di = PROTECT(coerceVector(di, INTSXP));
@@ -608,7 +607,7 @@ SEXP m_encodeInd2(SEXP i, SEXP j, SEXP di, SEXP orig_1, SEXP chk_bnds)
 {
 	SEXP ans;
 	int n = LENGTH(i), nprot = 1;
-	Rboolean check_bounds = asLogical(chk_bnds), one_ind = asLogical(orig_1);
+	int check_bounds = Rf_asLogical(chk_bnds), one_ind = Rf_asLogical(orig_1);
 
 	if (TYPEOF(di)!= INTSXP) {
 		di = PROTECT(coerceVector(di,INTSXP));
